# Changelog

## 2.2.0 (2025-03-11)

* feat: Update SDK to OpenAPI specification version 1.5.8 ([35bd7e1](https://github.com/MONEI/monei-python-sdk/commit/35bd7e1))
* refactor: Simplify signature verification and update commitlint config ([da7bea9](https://github.com/MONEI/monei-python-sdk/commit/da7bea9))

## 2.1.0 (2025-03-08)

* feat: Update SDK to OpenAPI specification version 1.5.7 ([39ace3a](https://github.com/MONEI/monei-python-sdk/commit/39ace3a))
* docs: Remove external documentation link from README ([766db44](https://github.com/MONEI/monei-python-sdk/commit/766db44))
* chore: Add commitlint and conventional changelog configuration ([04fa1f3](https://github.com/MONEI/monei-python-sdk/commit/04fa1f3))

All notable changes to this project will be documented in this file.
